# RPyServo

## Installation

pigpio is required for this package, if you do not have it, simply run:
<pre>$ pip install pigpio </pre>

Now, to install the package, simply run:
<pre>$ pip install RPyServo </pre>

## Description

A Python library to simplify the use of servos in RaspberryPi.

This inferface was created to simplify the pigpio interace, it is quite simple at the moment, but it manages the pigpio initialization and fixes the arbitrary servo angles of 500-2500 to 0-1000.

This is still a work in progress, so feel free to contribute!
